﻿CREATE DATABASE rae_publications;
USE rae_publications;

DROP TABLE IF EXISTS `departments`;
CREATE TABLE `departments` (
  `id` bigint(20) NOT NULL auto_increment,
  `higher_dept_id` bigint(20) default '0',
  `name` varchar(100) NOT NULL default '',
  `description` varchar(200) default NULL,
  PRIMARY KEY  (`id`),
  UNIQUE KEY `unique_dept_name` (`name`),
  UNIQUE KEY `unique_dept_desc` (`description`),
  KEY `higher_dept_id` (`higher_dept_id`),
  CONSTRAINT `departments_ibfk_1` FOREIGN KEY (`higher_dept_id`) REFERENCES `departments` (`id`) ON DELETE CASCADE
) ENGINE=InnoDB DEFAULT CHARSET=utf8;

DROP TABLE IF EXISTS `unit_of_assessment`;
CREATE TABLE `unit_of_assessment` (
  `id` bigint(20) NOT NULL auto_increment,
  `description` varchar(200) NOT NULL default '',
  PRIMARY KEY  (`id`),
  UNIQUE KEY `unique_uoa_desc` (`description`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COMMENT='InnoDB free: 5120 kB; (`department_id`) REFER `rae_publicati';


DROP TABLE IF EXISTS `unit_of_assessment_departments`;
CREATE TABLE `unit_of_assessment_departments` (
  `id` bigint(20) NOT NULL auto_increment,
  `uoa_id` bigint(20) NOT NULL,
  `department_id` bigint(20) NOT NULL,
  PRIMARY KEY  (`id`),
  UNIQUE KEY `unique_uoa_department` (`uoa_id`,`department_id`),
  CONSTRAINT `unit_of_assessment_departments_ibfk_1` FOREIGN KEY (`uoa_id`) REFERENCES `unit_of_assessment` (`id`) ON DELETE CASCADE,
  CONSTRAINT `unit_of_assessment_departments_ibfk_2` FOREIGN KEY (`uoa_id`) REFERENCES `unit_of_assessment` (`id`) ON DELETE CASCADE,
  CONSTRAINT `unit_of_assessment_departments_ibfk_3` FOREIGN KEY (`uoa_id`) REFERENCES `unit_of_assessment` (`id`) ON DELETE CASCADE
) ENGINE=InnoDB DEFAULT CHARSET=utf8;


DROP TABLE IF EXISTS `unit_of_assessment_size`;
CREATE TABLE `unit_of_assessment_size` (
  `uoa_name` varchar(100) NOT NULL,
  `size` int(11) NOT NULL,
  UNIQUE KEY `unique_uoa_size` (`uoa_name`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8;


DROP TABLE IF EXISTS `metadata_types`;
CREATE TABLE `metadata_types` (
  `id` bigint(20) NOT NULL auto_increment,
  `element` varchar(50) NOT NULL default '',
  `qualifier` varchar(50) default '',
  `comment` varchar(250) default NULL,
  `display_name` varchar(50) default NULL,
  `reg_ex` text NOT NULL,
  PRIMARY KEY  (`id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8;


DROP TABLE IF EXISTS `publication_types`;
CREATE TABLE `publication_types` (
  `id` bigint(20) NOT NULL auto_increment,
  `name` varchar(100) NOT NULL default '',
  PRIMARY KEY  (`id`),
  UNIQUE KEY `unique_name` (`name`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8;

DROP TABLE IF EXISTS `metadata_publication_types`;
CREATE TABLE `metadata_publication_types` (
  `id` bigint(20) NOT NULL auto_increment,
  `type_id` bigint(20) NOT NULL default '0',
  `publication_type_id` bigint(20) NOT NULL default '0',
  `mandatory` int(11) NOT NULL default '0',
  PRIMARY KEY  (`id`),
  UNIQUE KEY `unique_reference` (`type_id`,`publication_type_id`),
  KEY `publication_type_id` (`publication_type_id`),
  CONSTRAINT `metadata_publication_types_ibfk_1` FOREIGN KEY (`publication_type_id`) REFERENCES `publication_types` (`id`) ON DELETE CASCADE
) ENGINE=InnoDB DEFAULT CHARSET=utf8;

DROP TABLE IF EXISTS `users`;
CREATE TABLE `users` (
  `id` bigint(20) NOT NULL auto_increment,
  `username` varchar(100) NOT NULL default '',
  `department_id` bigint(20) default '0',
  `power_user` int(11) NOT NULL default '0',
  `admin_user` int(11) NOT NULL default '0',
  `created` date NOT NULL default '0000-00-00',
  `last_modified` date NOT NULL default '0000-00-00',
  `last_update_by` varchar(20) NOT NULL default '',
  `unit_code` varchar(6) default NULL,
  `staff_no` bigint(20) NOT NULL default '0',
  `initials` varchar(10) default NULL,
  `surname` varchar(150) default NULL,
  `uoa_id` int(11) default NULL,
  `password` varchar(100) default '',
  PRIMARY KEY  (`id`),
  UNIQUE KEY `unique_user_uun` (`username`),
  KEY `department_id` (`department_id`),
  CONSTRAINT `users_ibfk_1` FOREIGN KEY (`department_id`) REFERENCES `departments` (`id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8;


DROP TABLE IF EXISTS `items`;
CREATE TABLE `items` (
  `id` bigint(20) NOT NULL auto_increment,
  `submitter` bigint(20) NOT NULL default '0',
  `last_modified` date NOT NULL default '0000-00-00',
  `created` date NOT NULL default '0000-00-00',
  `publication_type_id` bigint(20) NOT NULL default '1',
  `ir_flag` int(11) default NULL,
  `ir_id` int(11) default NULL,
  PRIMARY KEY  (`id`),
  KEY `submitter` (`submitter`),
  KEY `publication_type_id` (`publication_type_id`),
  CONSTRAINT `items_ibfk_1` FOREIGN KEY (`submitter`) REFERENCES `users` (`id`),
  CONSTRAINT `items_ibfk_2` FOREIGN KEY (`publication_type_id`) REFERENCES `publication_types` (`id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8;


DROP TABLE IF EXISTS `metadata_values`;
CREATE TABLE `metadata_values` (
  `id` bigint(20) NOT NULL auto_increment,
  `type_id` bigint(20) NOT NULL default '0',
  `item_id` bigint(20) NOT NULL default '0',
  `value` text NOT NULL,
  `value_id` bigint(20) default NULL,
  PRIMARY KEY  (`id`),
  KEY `item_id` (`item_id`),
  KEY `value_id` (`value_id`),
  KEY `type_id` (`type_id`),
  CONSTRAINT `metadata_values_ibfk_1` FOREIGN KEY (`item_id`) REFERENCES `items` (`id`) ON DELETE CASCADE,
  CONSTRAINT `metadata_values_ibfk_2` FOREIGN KEY (`value_id`) REFERENCES `metadata_values` (`id`) ON DELETE CASCADE,
  CONSTRAINT `metadata_values_ibfk_3` FOREIGN KEY (`type_id`) REFERENCES `metadata_types` (`id`) ON DELETE CASCADE
) ENGINE=InnoDB DEFAULT CHARSET=utf8;



DROP TABLE IF EXISTS `files`;
CREATE TABLE `files` (
  `id` bigint(20) NOT NULL auto_increment,
  `item_id` bigint(20) NOT NULL default '0',
  `file` varchar(250) default NULL,
  `mimetype` varchar(100) default NULL,
  `checksum` varchar(250) default NULL,
  `checksum_type` varchar(100) default NULL,
  `original_url` varchar(250) default NULL,
  PRIMARY KEY  (`id`),
  UNIQUE KEY `unique_file` (`file`),
  KEY `item_id` (`item_id`),
  CONSTRAINT `files_ibfk_1` FOREIGN KEY (`item_id`) REFERENCES `items` (`id`) ON DELETE CASCADE,
  CONSTRAINT `files_ibfk_2` FOREIGN KEY (`item_id`) REFERENCES `items` (`id`) ON DELETE CASCADE
) ENGINE=InnoDB DEFAULT CHARSET=utf8;



DROP TABLE IF EXISTS `research_groups`;
CREATE TABLE `research_groups` (
  `id` bigint(20) NOT NULL auto_increment,
  `uoa` bigint(20) NOT NULL default '0',
  `name` varchar(50) NOT NULL default '',
  PRIMARY KEY  (`id`),
  KEY `uoa` (`uoa`),
  CONSTRAINT `research_groups_ibfk_1` FOREIGN KEY (`uoa`) REFERENCES `unit_of_assessment` (`id`) ON DELETE CASCADE
) ENGINE=InnoDB DEFAULT CHARSET=utf8;


DROP TABLE IF EXISTS `roles`;
CREATE TABLE `roles` (
  `role` varchar(20) NOT NULL,
  PRIMARY KEY  (`role`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8;


DROP TABLE IF EXISTS `staff`;
CREATE TABLE `staff` (
  `id` bigint(20) NOT NULL auto_increment,
  `staff_no` bigint(20) NOT NULL default '0',
  `uun` varchar(100) NOT NULL default '',
  `surname` varchar(50) NOT NULL default '',
  `initials` varchar(50) NOT NULL default '',
  `gender` char(1) NOT NULL default '',
  `birthyear` int(11) NOT NULL default '0',
  `category` char(1) NOT NULL default '',
  `rae` int(11) NOT NULL default '0',
  PRIMARY KEY  (`id`),
  UNIQUE KEY `unique_staff_uun` (`uun`),
  UNIQUE KEY `unique_staff_no` (`staff_no`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8;


DROP TABLE IF EXISTS `staff_departments`;
CREATE TABLE `staff_departments` (
  `id` bigint(20) NOT NULL auto_increment,
  `staff_id` bigint(20) NOT NULL,
  `department_id` bigint(20) NOT NULL,
  PRIMARY KEY  (`id`),
  UNIQUE KEY `unique_staff_departments` (`staff_id`,`department_id`),
  CONSTRAINT `staff_departments_ibfk_1` FOREIGN KEY (`staff_id`) REFERENCES `staff` (`id`) ON DELETE CASCADE,
  CONSTRAINT `staff_departments_ibfk_2` FOREIGN KEY (`staff_id`) REFERENCES `staff` (`id`) ON DELETE CASCADE,
  CONSTRAINT `staff_departments_ibfk_3` FOREIGN KEY (`staff_id`) REFERENCES `staff` (`id`) ON DELETE CASCADE
) ENGINE=InnoDB DEFAULT CHARSET=utf8;


DROP TABLE IF EXISTS `staff_items`;
CREATE TABLE `staff_items` (
  `id` bigint(20) NOT NULL auto_increment,
  `staff_id` bigint(20) NOT NULL default '0',
  `item_id` bigint(20) NOT NULL default '0',
  `number` int(11) default '0',
  `rae` int(10) unsigned NOT NULL default '0',
  `statement` text,
  PRIMARY KEY  (`id`),
  UNIQUE KEY `unique_staff_items` (`staff_id`,`item_id`),
  UNIQUE KEY `unique_staff_item` (`staff_id`,`item_id`,`number`),
  KEY `item_id` (`item_id`),
  CONSTRAINT `staff_items_ibfk_1` FOREIGN KEY (`staff_id`) REFERENCES `staff` (`id`) ON DELETE CASCADE,
  CONSTRAINT `staff_items_ibfk_2` FOREIGN KEY (`item_id`) REFERENCES `items` (`id`) ON DELETE CASCADE
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COMMENT='InnoDB free: 11264 kB; (`staff_id`) REFER `rae_publications/';


DROP TABLE IF EXISTS `staff_research_groups`;
CREATE TABLE `staff_research_groups` (
  `id` bigint(20) NOT NULL auto_increment,
  `staff_id` bigint(20) NOT NULL default '0',
  `research_group` bigint(20) NOT NULL default '0',
  PRIMARY KEY  (`id`),
  UNIQUE KEY `unique_staff_research` (`staff_id`,`research_group`),
  KEY `research_group` (`research_group`),
  CONSTRAINT `staff_research_groups_ibfk_1` FOREIGN KEY (`research_group`) REFERENCES `research_groups` (`id`) ON DELETE CASCADE
) ENGINE=InnoDB DEFAULT CHARSET=utf8;


DROP TABLE IF EXISTS `staff_unit_of_assessment`;
CREATE TABLE `staff_unit_of_assessment` (
  `id` bigint(20) NOT NULL auto_increment,
  `staff_id` bigint(20) NOT NULL,
  `uoa_id` bigint(20) NOT NULL,
  PRIMARY KEY  (`id`),
  UNIQUE KEY `unique_staff_unit_of_assessment` (`uoa_id`,`staff_id`),
  KEY `staff_id` (`staff_id`),
  CONSTRAINT `staff_unit_of_assessment_ibfk_1` FOREIGN KEY (`staff_id`) REFERENCES `staff` (`id`) ON DELETE CASCADE,
  CONSTRAINT `staff_unit_of_assessment_ibfk_2` FOREIGN KEY (`uoa_id`) REFERENCES `unit_of_assessment` (`id`) ON DELETE CASCADE,
  CONSTRAINT `staff_unit_of_assessment_ibfk_3` FOREIGN KEY (`staff_id`) REFERENCES `staff` (`id`) ON DELETE CASCADE,
  CONSTRAINT `staff_unit_of_assessment_ibfk_4` FOREIGN KEY (`uoa_id`) REFERENCES `unit_of_assessment` (`id`) ON DELETE CASCADE,
  CONSTRAINT `staff_unit_of_assessment_ibfk_5` FOREIGN KEY (`staff_id`) REFERENCES `staff` (`id`) ON DELETE CASCADE,
  CONSTRAINT `staff_unit_of_assessment_ibfk_6` FOREIGN KEY (`uoa_id`) REFERENCES `unit_of_assessment` (`id`) ON DELETE CASCADE
) ENGINE=InnoDB DEFAULT CHARSET=utf8;


DROP TABLE IF EXISTS `user_roles`;
CREATE TABLE `user_roles` (
  `id` bigint(20) NOT NULL auto_increment,
  `role` varchar(20) NOT NULL default '',
  `username` varchar(100) NOT NULL default '',
  `user_id` bigint(20) NOT NULL default '0',
  PRIMARY KEY  (`id`),
  UNIQUE KEY `unique_user_role` (`username`,`role`),
  KEY `FK_user_roles_1` (`user_id`),
  KEY `FK_user_roles_2` (`role`),
  CONSTRAINT `FK_user_roles_1` FOREIGN KEY (`user_id`) REFERENCES `users` (`id`) ON DELETE CASCADE,
  CONSTRAINT `FK_user_roles_2` FOREIGN KEY (`role`) REFERENCES `roles` (`role`) ON DELETE CASCADE
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COMMENT='InnoDB free: 15360 kB; (`role`) REFER `irra_publications/rol';





